History
=======

0.1.0 (2021-10-02)
------------------

* First release on PyPI.

0.2.0 (2021-10-04)
------------------

* Added: optional filter by ids
* Added: optional print STAC query
* Updated: docs